@@ -1,6 +1,6 @@
 package DBD::Oracle::Troubleshooting;
 {
-  $DBD::Oracle::Troubleshooting::VERSION = '1.44';
+  $DBD::Oracle::Troubleshooting::VERSION = '1.46';
 }
 BEGIN {
   $DBD::Oracle::Troubleshooting::AUTHORITY = 'cpan:PYTHIAN';
@@ -17,7 +17,7 @@ DBD::Oracle::Troubleshooting - Tips and Hints to Troubleshoot DBD::Oracle
 
 =head1 VERSION
 
-version 1.44
+version 1.46
 
 =head1 CONNECTING TO ORACLE
 
@@ -363,6 +363,18 @@ oracle table implementation, and no UTF support.
 Oracle 9.0 is uncertain, since testing has not been possible yet,
 but the remedy will not hurt :)
 
+=head1 Miscellaneous
+
+=head2 Crash with an open connection and Module::Runtime in mod_perl2
+
+See RT 72989 (https://rt.cpan.org/Ticket/Display.html?id=72989)
+
+Apache2 MPM Prefork with mod_perl2 will crash if Module::Runtime is
+loaded, and an Oracle connection is opened through PerlRequire (before
+forking).
+
+It looks like this was fixed in 0.012 of Module::Runtime.
+
 =head1 AUTHORS
 
 =over 4
@@ -379,6 +391,10 @@ John Scoles
 
 Yanick Champoux <yanick@cpan.org>
 
+=item *
+
+Martin J. Evans <mjevans@cpan.org>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
